.. thebrog documentation master file, created by
   sphinx-quickstart on Tue Feb 16 13:03:42 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

***********
gaussdecomp
***********

Introduction
============
|gaussdecomp| is a package to Gaussian Decomposition emission line spectra, for example
HI spectra.  It also will run on an entire datacube at once.


.. toctree::
   :maxdepth: 1

   install
   gettingstarted
   modules
   

Examples
========

.. toctree::
    :maxdepth: 1

    examples

*****
Index
*****

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
